@@ -2,9 +2,9 @@ import datetime
 import getpass
 import os
 import sys
-from orionis.console.output.styles import ANSIColors
-from orionis._contracts.console.output.console import IConsole
-from orionis.services.formatter.serializer import Parser
+from orionis.console.output.enums import ANSIColors
+from orionis.console.output.contracts.console import IConsole
+from orionis.support.formatter.serializer import Parser
 
 class Console(IConsole):
     """
@@ -14,8 +14,7 @@ class Console(IConsole):
     optional timestamps, as well as general text formatting methods.
     """
 
-    @staticmethod
-    def _get_timestamp() -> str:
+    def __getTimestamp(self) -> str:
         """
         Returns the current date and time formatted in a muted color.
 
@@ -26,8 +25,7 @@ class Console(IConsole):
         """
         return f"{ANSIColors.TEXT_MUTED.value}{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')}{ANSIColors.DEFAULT.value}"
 
-    @staticmethod
-    def _print_with_background(label: str, bg_color: ANSIColors, message: str, timestamp: bool):
+    def __printWithBackground(self, label: str, bg_color: ANSIColors, message: str, timestamp: bool):
         """
         Prints a formatted message with a background color.
 
@@ -42,11 +40,10 @@ class Console(IConsole):
         timestamp : bool
             Whether to include a timestamp.
         """
-        str_time = Console._get_timestamp() if timestamp else ''
+        str_time = self.__getTimestamp() if timestamp else ''
         print(f"{bg_color.value}{ANSIColors.TEXT_WHITE.value} {label} {ANSIColors.DEFAULT.value} {str_time} {message}{ANSIColors.DEFAULT.value}")
 
-    @staticmethod
-    def _print_colored(message: str, text_color: ANSIColors):
+    def __printColored(self, message: str, text_color: ANSIColors):
         """
         Prints a message with a specified text color.
 
@@ -59,8 +56,7 @@ class Console(IConsole):
         """
         print(f"{text_color.value}{message}{ANSIColors.DEFAULT.value}")
 
-    @staticmethod
-    def success(message: str, timestamp: bool = True):
+    def success(self, message: str, timestamp: bool = True):
         """
         Prints a success message with a green background.
 
@@ -71,10 +67,9 @@ class Console(IConsole):
         timestamp : bool, optional
             Whether to include a timestamp (default is True).
         """
-        Console._print_with_background("SUCCESS", ANSIColors.BG_SUCCESS, message, timestamp)
+        self.__printWithBackground("SUCCESS", ANSIColors.BG_SUCCESS, message, timestamp)
 
-    @staticmethod
-    def textSuccess(message: str):
+    def textSuccess(self, message: str):
         """
         Prints a success message in green.
 
@@ -83,10 +78,9 @@ class Console(IConsole):
         message : str
             The success message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_SUCCESS)
+        self.__printColored(message, ANSIColors.TEXT_SUCCESS)
 
-    @staticmethod
-    def textSuccessBold(message: str):
+    def textSuccessBold(self, message: str):
         """
         Prints a bold success message in green.
 
@@ -95,10 +89,9 @@ class Console(IConsole):
         message : str
             The success message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_BOLD_SUCCESS)
+        self.__printColored(message, ANSIColors.TEXT_BOLD_SUCCESS)
 
-    @staticmethod
-    def info(message: str, timestamp: bool = True):
+    def info(self, message: str, timestamp: bool = True):
         """
         Prints an informational message with a blue background.
 
@@ -109,10 +102,9 @@ class Console(IConsole):
             timestamp : bool, optional
             Whether to include a timestamp (default is True).
         """
-        Console._print_with_background("INFO", ANSIColors.BG_INFO, message, timestamp)
+        self.__printWithBackground("INFO", ANSIColors.BG_INFO, message, timestamp)
 
-    @staticmethod
-    def textInfo(message: str):
+    def textInfo(self, message: str):
         """
         Prints an informational message in blue.
 
@@ -121,10 +113,9 @@ class Console(IConsole):
         message : str
             The informational message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_INFO)
+        self.__printColored(message, ANSIColors.TEXT_INFO)
 
-    @staticmethod
-    def textInfoBold(message: str):
+    def textInfoBold(self, message: str):
         """
         Prints a bold informational message in blue.
 
@@ -133,10 +124,9 @@ class Console(IConsole):
         message : str
             The informational message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_BOLD_INFO)
+        self.__printColored(message, ANSIColors.TEXT_BOLD_INFO)
 
-    @staticmethod
-    def warning(message: str, timestamp: bool = True):
+    def warning(self, message: str, timestamp: bool = True):
         """
         Prints a warning message with a yellow background.
 
@@ -147,10 +137,9 @@ class Console(IConsole):
             timestamp : bool, optional
             Whether to include a timestamp (default is True).
         """
-        Console._print_with_background("WARNING", ANSIColors.BG_WARNING, message, timestamp)
+        self.__printWithBackground("WARNING", ANSIColors.BG_WARNING, message, timestamp)
 
-    @staticmethod
-    def textWarning(message: str):
+    def textWarning(self, message: str):
         """
         Prints a warning message in yellow.
 
@@ -159,10 +148,9 @@ class Console(IConsole):
         message : str
             The warning message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_WARNING)
+        self.__printColored(message, ANSIColors.TEXT_WARNING)
 
-    @staticmethod
-    def textWarningBold(message: str):
+    def textWarningBold(self, message: str):
         """
         Prints a bold warning message in yellow.
 
@@ -171,10 +159,9 @@ class Console(IConsole):
         message : str
             The warning message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_BOLD_WARNING)
+        self.__printColored(message, ANSIColors.TEXT_BOLD_WARNING)
 
-    @staticmethod
-    def fail(message: str, timestamp: bool = True):
+    def fail(self, message: str, timestamp: bool = True):
         """
         Prints a failure message with a red background.
 
@@ -185,10 +172,9 @@ class Console(IConsole):
             timestamp : bool, optional
             Whether to include a timestamp (default is True).
         """
-        Console._print_with_background("FAIL", ANSIColors.BG_FAIL, message, timestamp)
+        self.__printWithBackground("FAIL", ANSIColors.BG_FAIL, message, timestamp)
 
-    @staticmethod
-    def error(message: str, timestamp: bool = True):
+    def error(self, message: str, timestamp: bool = True):
         """
         Prints an error message with a red background.
 
@@ -199,10 +185,9 @@ class Console(IConsole):
             timestamp : bool, optional
             Whether to include a timestamp (default is True).
         """
-        Console._print_with_background("ERROR", ANSIColors.BG_ERROR, message, timestamp)
+        self.__printWithBackground("ERROR", ANSIColors.BG_ERROR, message, timestamp)
 
-    @staticmethod
-    def textError(message: str):
+    def textError(self, message: str):
         """
         Prints an error message in red.
 
@@ -211,10 +196,9 @@ class Console(IConsole):
         message : str
             The error message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_ERROR)
+        self.__printColored(message, ANSIColors.TEXT_ERROR)
 
-    @staticmethod
-    def textErrorBold(message: str):
+    def textErrorBold(self, message: str):
         """
         Prints a bold error message in red.
 
@@ -223,10 +207,9 @@ class Console(IConsole):
         message : str
             The error message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_BOLD_ERROR)
+        self.__printColored(message, ANSIColors.TEXT_BOLD_ERROR)
 
-    @staticmethod
-    def textMuted(message: str):
+    def textMuted(self, message: str):
         """
         Prints a muted (gray) message.
 
@@ -235,10 +218,9 @@ class Console(IConsole):
         message : str
             The message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_MUTED)
+        self.__printColored(message, ANSIColors.TEXT_MUTED)
 
-    @staticmethod
-    def textMutedBold(message: str):
+    def textMutedBold(self, message: str):
         """
         Prints a bold muted (gray) message.
 
@@ -247,10 +229,9 @@ class Console(IConsole):
         message : str
             The message to print.
         """
-        Console._print_colored(message, ANSIColors.TEXT_BOLD_MUTED)
+        self.__printColored(message, ANSIColors.TEXT_BOLD_MUTED)
 
-    @staticmethod
-    def textUnderline(message: str):
+    def textUnderline(self, message: str):
         """
         Prints an underlined message.
 
@@ -261,30 +242,26 @@ class Console(IConsole):
         """
         print(f"{ANSIColors.TEXT_STYLE_UNDERLINE.value}{message}{ANSIColors.DEFAULT.value}")
 
-    @staticmethod
-    def clear():
+    def clear(self):
         """
         Clears the console screen.
         """
         os.system('cls' if os.name == 'nt' else 'clear')
 
-    @staticmethod
-    def clearLine():
+    def clearLine(self):
         """
         Clears the current line in the console.
         """
         sys.stdout.write("\r \r")
         sys.stdout.flush()
 
-    @staticmethod
-    def line():
+    def line(self):
         """
         Prints a horizontal line in the console.
         """
         print("\n", end="")
 
-    @staticmethod
-    def newLine(count: int = 1):
+    def newLine(self, count: int = 1):
         """
         Prints multiple new lines.
 
@@ -302,8 +279,7 @@ class Console(IConsole):
             raise ValueError(f"Unsupported Value '{count}'")
         print("\n" * count, end="")
 
-    @staticmethod
-    def write(message: str):
+    def write(self, message: str):
         """
         Prints a message without moving to the next line.
 
@@ -315,8 +291,7 @@ class Console(IConsole):
         sys.stdout.write(f"{message}")
         sys.stdout.flush()
 
-    @staticmethod
-    def writeLine(message: str):
+    def writeLine(self, message: str):
         """
         Prints a message and moves to the next line.
 
@@ -327,8 +302,7 @@ class Console(IConsole):
         """
         print(f"{message}")
 
-    @staticmethod
-    def ask(question: str) -> str:
+    def ask(self, question: str) -> str:
         """
         Prompts the user for input with a message and returns the user's response.
 
@@ -344,8 +318,7 @@ class Console(IConsole):
         """
         return input(f"{ANSIColors.TEXT_INFO.value}{str(question).strip()}{ANSIColors.DEFAULT.value} ")
 
-    @staticmethod
-    def confirm(question: str, default: bool = False) -> bool:
+    def confirm(self, question: str, default: bool = False) -> bool:
         """
         Asks a confirmation question and returns True or False based on the user's response.
 
@@ -366,8 +339,7 @@ class Console(IConsole):
         response = input(f"{ANSIColors.TEXT_INFO.value}{str(question).strip()} (Y/n): {ANSIColors.DEFAULT.value} ").upper()
         return default if not response else str(response).upper in ["Y", "YES"]
 
-    @staticmethod
-    def secret(question: str) -> str:
+    def secret(self, question: str) -> str:
         """
         Prompts the user for hidden input, typically used for password input.
 
@@ -383,8 +355,7 @@ class Console(IConsole):
         """
         return getpass.getpass(f"{ANSIColors.TEXT_INFO.value}{str(question).strip()}{ANSIColors.DEFAULT.value} ")
 
-    @staticmethod
-    def table(headers: list, rows: list):
+    def table(self, headers: list, rows: list):
         """
         Prints a table in the console with the given headers and rows, with bold headers.
 
@@ -431,8 +402,7 @@ class Console(IConsole):
 
         print(bottom_border)
 
-    @staticmethod
-    def anticipate(question: str, options: list, default=None):
+    def anticipate(self, question: str, options: list, default=None):
         """
         Provides autocomplete suggestions based on user input.
 
@@ -463,8 +433,7 @@ class Console(IConsole):
         # Find the first option that starts with the input value, or use the default value
         return next((option for option in options if option.startswith(input_value)), default or input_value)
 
-    @staticmethod
-    def choice(question: str, choices: list, default_index: int = 0) -> str:
+    def choice(self, question: str, choices: list, default_index: int = 0) -> str:
         """
         Allows the user to select an option from a list.
 
@@ -518,8 +487,7 @@ class Console(IConsole):
 
         return choices[int(answer) - 1]
 
-    @staticmethod
-    def exception(e) -> None:
+    def exception(self, e) -> None:
         """
         Prints an exception message with detailed information.
 
@@ -558,8 +526,7 @@ class Console(IConsole):
 
         print("▬" * len(f" [{error_type}] : {error_message}"))
 
-    @staticmethod
-    def exitSuccess(message: str = None) -> None:
+    def exitSuccess(self, message: str = None) -> None:
         """
         Exits the program with a success message.
 
@@ -569,11 +536,10 @@ class Console(IConsole):
             The success message to print before exiting.
         """
         if message:
-            Console.success(message)
+            self.success(message)
         sys.exit(0)
 
-    @staticmethod
-    def exitError(message: str = None) -> None:
+    def exitError(self, message: str = None) -> None:
         """
         Exits the program with an error message.
 
@@ -583,5 +549,5 @@ class Console(IConsole):
             The error message to print before exiting.
         """
         if message:
-            Console.error(message)
+            self.error(message)
         sys.exit(1)
\ No newline at end of file
