@@ -10,9 +10,11 @@ from contextlib import redirect_stdout, redirect_stderr
 from datetime import datetime
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
+from orionis.container.resolver.resolver import Resolver
+from orionis.foundation.contracts.application import IApplication
 from orionis.services.introspection.instances.reflection import ReflectionInstance
 from orionis.services.system.workers import Workers
-from orionis.test.entities.test_result import TestResult
+from orionis.test.entities.result import TestResult
 from orionis.test.enums import (
     ExecutionMode,
     TestStatus
@@ -22,7 +24,7 @@ from orionis.test.exceptions import (
     OrionisTestPersistenceError,
     OrionisTestValueError
 )
-from orionis.test.logs.history import TestHistory
+from orionis.test.records.logs import TestLogs
 from orionis.test.contracts.unit_test import IUnitTest
 from orionis.test.output.printer import TestPrinter
 from orionis.test.view.render import TestingResultRender
@@ -42,7 +44,9 @@ class UnitTest(IUnitTest):
     This is an especially suitable choice for those seeking greater robustness, traceability, and visibility in their automated testing processes, offering advantages often missing from other alternatives.
     """
 
-    def __init__(self) -> None:
+    def __init__(
+        self
+    ) -> None:
         """
         Initializes the test suite configuration and supporting components.
 
@@ -100,28 +104,30 @@ class UnitTest(IUnitTest):
             Result of the test execution.
         """
 
+        # Value for application instance
+        self.app: Optional[IApplication] = None
+
         # Values for configuration
-        self.verbosity: int
-        self.execution_mode: str
-        self.max_workers: int
-        self.fail_fast: bool
-        self.print_result: bool
-        self.throw_exception: bool
-        self.persistent: bool
-        self.persistent_driver: str
-        self.web_report: bool
+        self.verbosity: Optional[int] = None
+        self.execution_mode: Optional[str] = None
+        self.max_workers: Optional[int] = None
+        self.fail_fast: Optional[bool] = None
+        self.print_result: Optional[bool] = None
+        self.throw_exception: Optional[bool] = None
+        self.persistent: Optional[bool] = None
+        self.persistent_driver: Optional[str] = None
+        self.web_report: Optional[bool] = None
 
         # Values for discovering tests in folders
-        self.full_path: Optional[str]
-        self.folder_path: str
-        self.base_path: str
-        self.pattern: str
-        self.test_name_pattern: Optional[str]
-        self.tags: Optional[List[str]]
+        self.full_path: Optional[str] = None
+        self.folder_path: Optional[str] = None
+        self.base_path: Optional[str] = None
+        self.pattern: Optional[str] = None
+        self.test_name_pattern: Optional[str] = None
+        self.tags: Optional[List[str]] = None
 
         # Values for discovering tests in modules
-        self.module_name: str
-        self.test_name_pattern: Optional[str]
+        self.module_name: Optional[str] = None
 
         # Initialize the test loader and suite
         self.loader = unittest.TestLoader()
@@ -138,6 +144,33 @@ class UnitTest(IUnitTest):
         # Result of the test execution
         self.__result = None
 
+    def setApplication(
+        self,
+        app: 'IApplication'
+    ) -> 'UnitTest':
+        """
+        Set the application instance for the UnitTest.
+        This method allows the UnitTest to access the application instance, which is necessary for resolving dependencies and executing tests.
+
+        Parameters
+        ----------
+        app : IApplication
+            The application instance to be set for the UnitTest.
+
+        Returns
+        -------
+        UnitTest
+        """
+
+        # Validate the provided application instance
+        if not isinstance(app, IApplication):
+            raise OrionisTestValueError(
+                f"The provided application is not a valid instance of IApplication: {type(app).__name__}."
+            )
+
+        # Set the application instance
+        self.app = app
+
     def configure(
             self,
             *,
@@ -632,6 +665,117 @@ class UnitTest(IUnitTest):
         # Return the result along with captured output and error streams
         return result, output_buffer, error_buffer
 
+    def __resolveFlattenedTestSuite(
+        self
+    ) -> unittest.TestSuite:
+        """
+        Resolves dependencies for all test cases in the suite and creates a flattened test suite with injected dependencies.
+
+        Processes each test case, identifies dependencies in test method signatures, and resolves
+        them using the application's dependency resolver. Creates wrapper methods that automatically
+        inject the resolved dependencies when tests are executed.
+
+        Parameters
+        ----------
+        None
+
+        Returns
+        -------
+        unittest.TestSuite
+            A new test suite with all tests having their dependencies resolved and injected.
+
+        Raises
+        ------
+        OrionisTestValueError
+            If any test method has dependencies that cannot be resolved.
+
+        Notes
+        -----
+        - Test methods with decorators are left as-is
+        - Test methods without dependencies are added directly
+        - Test methods with unresolved dependencies trigger an error
+        """
+
+        # Create a new test suite with tests that have their dependencies resolved
+        flattened_suite = unittest.TestSuite()
+
+        # Iterate through all test cases
+        for test_case in self.__flattenTestSuite(self.suite):
+
+            # Get the test method name
+            method_name = ReflectionInstance(test_case).getAttribute("_testMethodName")
+
+            # Is not method_name, use the original test case
+            if not method_name:
+                flattened_suite.addTest(test_case)
+                continue
+
+            # Get the actual method object
+            test_method = getattr(test_case.__class__, method_name, None)
+
+            # Check for all decorators on the test method
+            decorators = []
+
+            # Get decorators from the test method
+            if hasattr(test_method, '__wrapped__'):
+                original = test_method
+                while hasattr(original, '__wrapped__'):
+                    # Try to get decorator name
+                    if hasattr(original, '__qualname__'):
+                        decorators.append(original.__qualname__)
+                    elif hasattr(original, '__name__'):
+                        decorators.append(original.__name__)
+                    original = original.__wrapped__
+
+            # If use decorators, use original test method
+            if decorators:
+                flattened_suite.addTest(test_case)
+                continue
+
+            # Extract dependencies for the test method
+            signature = ReflectionInstance(test_case).getMethodDependencies(method_name)
+
+            # If no dependencies to resolve, just add the original test
+            if (not signature.resolved and not signature.unresolved) or \
+               (not signature.resolved and len(signature.unresolved) > 0):
+                flattened_suite.addTest(test_case)
+                continue
+
+            # If there are unresolved dependencies, raise an error
+            if (len(signature.unresolved) > 0):
+                raise OrionisTestValueError(
+                    f"Test method '{method_name}' in class '{test_case.__class__.__name__}' has unresolved dependencies: {signature.unresolved}. "
+                    "Please ensure all dependencies are correctly defined and available."
+                )
+
+            # Create a specialized test case with resolved dependencies
+            test_class = ReflectionInstance(test_case).getClass()
+            original_method = getattr(test_class, method_name)
+
+            # Create a dict of resolved dependencies
+            params = Resolver(self.app).resolveSignature(signature)
+
+            # Create a wrapper method that injects dependencies
+            def create_test_wrapper(original_test, resolved_args:dict):
+                def wrapper(self_instance):
+                    return original_test(self_instance, **resolved_args)
+                return wrapper
+
+            # Create the wrapped method with injected dependencies
+            wrapped_method = create_test_wrapper(original_method, params)
+
+            # Bind the wrapped method to the test case instance
+            bound_method = wrapped_method.__get__(test_case, test_case.__class__)
+
+            # Replace the original test method with the wrapped method
+            setattr(test_case, method_name, bound_method)
+
+            # Add the modified test case to the suite
+            flattened_suite.addTest(test_case)
+
+        # Return the flattened suite with resolved dependencies
+        return flattened_suite
+
     def __runTestsSequentially(
         self,
         output_buffer: io.StringIO,
@@ -654,9 +798,6 @@ class UnitTest(IUnitTest):
             passed, failed, and skipped tests.
         """
 
-        # Flatten the suite to avoid duplicate tests
-        flattened_suite = unittest.TestSuite(self.__flattenTestSuite(self.suite))
-
         # Create a custom result class to capture detailed test results
         with redirect_stdout(output_buffer), redirect_stderr(error_buffer):
             runner = unittest.TextTestRunner(
@@ -665,7 +806,7 @@ class UnitTest(IUnitTest):
                 failfast=self.fail_fast,
                 resultclass=self.__customResultClass()
             )
-            result = runner.run(flattened_suite)
+            result = runner.run(self.__resolveFlattenedTestSuite())
 
         # Return the result object containing test outcomes
         return result
@@ -699,7 +840,7 @@ class UnitTest(IUnitTest):
         """
 
         # Flatten the test suite to get individual test cases
-        test_cases = list(self.__flattenTestSuite(self.suite))
+        test_cases = list(self.__resolveFlattenedTestSuite())
 
         # Create a custom result instance to collect all results
         result_class = self.__customResultClass()
@@ -1108,7 +1249,7 @@ class UnitTest(IUnitTest):
         Notes
         -----
         Depending on the value of `self.persistent_driver`, the summary is either:
-            - Stored in an SQLite database (using the TestHistory class), or
+            - Stored in an SQLite database (using the TestLogs class), or
             - Written to a timestamped JSON file in the specified base path.
 
         Raises
@@ -1129,8 +1270,8 @@ class UnitTest(IUnitTest):
 
             if self.persistent_driver == 'sqlite':
 
-                # Initialize the TestHistory class for database operations
-                history = TestHistory(
+                # Initialize the TestLogs class for database operations
+                history = TestLogs(
                     storage_path=storage_path,
                     db_name='tests.sqlite',
                     table_name='reports'
