@@ -1,9 +1,9 @@
 from orionis.services.introspection.abstract.reflection import ReflectionAbstract
 from orionis.services.introspection.dependencies.entities.class_dependencies import ClassDependency
 from tests.services.inspection.reflection.mock.fake_reflect_instance import AbstractFakeClass
-from orionis.unittesting import TestCase
+from orionis.test.cases.asynchronous import AsyncTestCase
 
-class TestServiceReflectionAbstract(TestCase):
+class TestServiceReflectionAbstract(AsyncTestCase):
 
     async def testGetClass(self):
         """
